@@ -18,7 +18,7 @@
 # along with mb-netmgmt. If not, see <https://www.gnu.org/licenses/
 
 """Network Management Protocols for Mountebank"""
-__version__ = "0.0.45"
+__version__ = "0.0.51"
 
 import os
 import subprocess
@@ -26,14 +26,15 @@ import time
 from contextlib import contextmanager
 
 import requests
-import yaml
+from ruamel.yaml import YAML
+from ruamel.yaml.scalarstring import walk_tree
+
+yaml = YAML()
 
 
 @contextmanager
 def mb(imposters, loglevel="info"):
-    with subprocess.Popen(
-        ["mb", "--loglevel", loglevel], cwd=os.path.dirname(__file__)
-    ) as mb:
+    with start_mb(loglevel) as mb:
         try:
             put_imposters("localhost", imposters)
             yield mb
@@ -41,11 +42,18 @@ def mb(imposters, loglevel="info"):
             mb.terminate()
 
 
-def put_imposters(host, imposters):
+def start_mb(loglevel="info"):
+    return subprocess.Popen(
+        ["mb", "--loglevel", loglevel, "--pidfile", "/tmp/mb.pid"],
+        cwd=os.path.dirname(__file__),
+    )
+
+
+def put_imposters(host, imposters, port=2525):
     while True:
         try:
             response = requests.put(
-                f"http://{host}:2525/imposters",
+                f"http://{host}:{port}/imposters",
                 json={"imposters": imposters},
             )
             break
@@ -57,18 +65,18 @@ def put_imposters(host, imposters):
         raise RuntimeError(e.response.json()["errors"])
 
 
-def dump_imposters(host, name):
+def dump_imposters(host="localhost", name="imposters", port=2525):
+    imposters = get_imposters(host, port)
+    walk_tree(imposters)
+    yaml.dump(imposters, open(f"{name}.yaml", "w"))
+
+
+def get_imposters(host="localhost", port=2525):
     response = requests.get(
-        f"http://{host}:2525/imposters",
+        f"http://{host}:{port}/imposters",
         {"replayable": True, "removeProxies": True},
     )
-
-    def str_presenter(dumper, data):
-        style = "|" if len(data.splitlines()) > 1 else None
-        return dumper.represent_scalar("tag:yaml.org,2002:str", data, style=style)
-
-    yaml.representer.SafeRepresenter.add_representer(str, str_presenter)
-    yaml.safe_dump(response.json(), open(f"{name}.yaml", "w"), width=None)
+    return response.json()
 
 
 def load_imposters(host, name):
@@ -76,7 +84,7 @@ def load_imposters(host, name):
 
 
 def read_imposters(name):
-    return yaml.safe_load(open(f"{name}.yaml").read())["imposters"]
+    return yaml.load(open(f"{name}.yaml"))["imposters"]
 
 
 def proxy_imposters(to, snmp_port=161, telnet_port=23, netconf_port=830):
